mgkit.io package
================

Submodules
----------

.. toctree::

   mgkit.io.blast
   mgkit.io.fasta
   mgkit.io.fastq
   mgkit.io.gff
   mgkit.io.glimmer
   mgkit.io.snpdat
   mgkit.io.uniprot
   mgkit.io.utils

Module contents
---------------

.. automodule:: mgkit.io
   :members:
   :undoc-members:
   :show-inheritance:
